Isso
====

What's Isso?
------------

Isso is a lightweight commenting server similar to Disqus. It allows anonymous
comments, maintains identity and is simple to administrate. It uses JavaScript
and cross-origin ressource sharing for easy integration into static websites.

No, I meant "Isso"
------------------

Isso is an informal, german abbreviation for "Ich schrei sonst!", which can
roughly be translated to "I'm yelling otherwise". It usually ends the
discussion without any further arguments.

In germany, Isso `is also pokémon N° 360`__.

.. __: http://bulbapedia.bulbagarden.net/wiki/Wynaut_(Pok%C3%A9mon)

What's wrong with Disqus?
-------------------------

No anonymous comments (IP address, email and name recorded), hosted in the USA,
third-party. Just like IntenseDebate, livefrye etc. When you embed Disqus, they
can do anything with your readers (and probably mine Bitcoins, see the loading
times).

Setup
-----

.. toctree::
   :maxdepth: 1

   ../quickstart
   ../troubleshooting

